/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ManageProducts.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.geolocation.web.back;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.List;
import javax.ejb.EJB;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.ow2.util.geolocation.business.GeoLocatorInterface;
import org.ow2.util.geolocation.business.entity.ManagedProduct;

/**
 * The management interface of the app.
 * 
 * @author mancelin
 */
public class ManageProducts extends HttpServlet {

    /**
     * A null string.
     */
    private static final String NULL = "";
    /**
     * The geolocalization EJB.
     */
    @EJB
    private GeoLocatorInterface clientSess;

    /**
     * Processes requests for both HTTP <code>GET</code> and <code>POST</code> methods.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    protected void processRequest(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        response.setContentType("text/html;charset=UTF-8");
        PrintWriter out = response.getWriter();

        String productname = request.getParameter("productname");
        String productversion = request.getParameter("productversion");
        
        String[] selected = request.getParameterValues("select");

        if (productversion != null && productname != null) {
            clientSess.addManagedProduct(productname, productversion);
        }

        if (selected != null) {
            if (selected.length > 0) {
                for (int i = 0; i < selected.length; i++) {
                    clientSess.removeManagedProduct(Long.valueOf(selected[i]));
                }
            }
        }

        try {
            out.println("<html>");
            out.println("<head>");
            out.println("<title>OW2 Products Users product management</title>");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + "rel=\"stylesheet\" type=\"text/css\"  />");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + " rel=\"stylesheet\" type=\"text/css\" title=\"default\" />");
            out.println("<link href=\"http://wiki.jonas.ow2.org/xwiki/bin/skin/XWiki/MySkin/style.css\""
                    + " rel=\"alternate stylesheet\" type=\"text/css\"  title=\"Alternate StyleSheet 1\" />");
            out.println("</head>");
            out.println("<body>");
            out.println("<div id=\"content\">");
            out.println("<a href=\"http://www.ow2.org/\">");
            out.println("<img src=\"/OW2ProductsService/header.jpg\""
                    + " alt=\"JOnAS header\" />");
            out.println("</a>");
            out.println("<div id=\"ow2logo\">");
            out.println("<a href=\"http://www.ow2.org\">");
            out.println("<img src=\"http://wiki.jonas.ow2.org/xwiki/bin/download/XWiki/MySkin/ow2_small.png\""
                    + " alt=\"OW2\" title=\"OW2\" />");
            out.println("</a>");
            out.println("</div>");
            out.println("<div id=\"communitylinks\">");
            out.println("<ul>");
            out.println("<li><a title=\"Users Map\" href=\"/OW2ProductsMap/\">Users Map</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a title=\"Admin\" href=\"/OW2ProductsService/mgmt.html\">Admin</a></li>");
            out.println("<li>|</li>");

            out.println("<li><a href=\"/OW2ProductsService/mgmt/showAll\">Manage records</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/mgmt/manage\">Manage products</a></li>");
            out.println("<li>|</li>");
            out.println("<li><a href=\"/OW2ProductsService/logout\">Logout</a></li>");
            out.println("</ul>");
            out.println("</div>");
            out.println("<h1 align=\"center\">OW2 Products Users manage products</h1>");
            out.println("<div align=\"center\">");
            out.println("<br/>");
            out.println("<br/>");
            

            List productsList = clientSess.findAllManagedProducts();


            out.println("<FORM method=post action=\"manage\">");
            out.println("<TABLE ALIGN=\"middle\">");
            out.println("<TR>");
            out.println("<TD>product name <INPUT name=\"productname\" type=\"text\"/></TD>");
            out.println("<TD>product version <INPUT name=\"productversion\" type=\"text\"/></TD>");
            out.println("<TD><INPUT type=\"submit\" value=\"Add\"/></TD></TR></TABLE>");
            out.println("</FORM>");

            out.println("<FORM method=post action=\"manage\">");
            out.println("<TABLE ALIGN=\"middle\">");
            out.println("<TR>");
            out.println("<TD>Remove selected products ");
            out.println("<TD><INPUT type=\"submit\" value=\"Remove\"/></TD></TR></TABLE>");
            out.println("<br/>");

            out.println("<TABLE BORDER=\"1\" ALIGN=\"middle\" CELLPADDING=5>");
            out.println("<TR BGCOLOR=\"#FFFFB0\">");
            out.println("<TH> Select </TH>");
            out.println("<TH> ID </TH>");
            out.println("<TH> Name </TH>");
            out.println("<TH> Version </TH>");
            
            out.println("</TR>");
            for (ManagedProduct p : (List<ManagedProduct>) productsList) {
                out.println("<TR>");
                out.println("<TD align=\"center\"> <INPUT type=\"checkbox\" name=\"select\" value=\"" + p.getId() + "\"/></TD>");
                out.println("<TD align=\"center\"> " + p.getId() + " </TD>");
                out.println("<TD align=\"center\"> " + p.getName() + " </TD>");
                out.println("<TD align=\"center\"> " + p.getVersion() + " </TD>");
                out.println("</TR>");
            }
            out.println("</TABLE>");
            out.println("<br/>");
            out.println("<br/>");
            out.println("</div>");
            out.println("</div>");
            out.println("</FORM>");
            out.println("</body>");
            out.println("</html>");
        } finally {
            out.close();
        }
    }

    /** 
     * Handles the HTTP <code>GET</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Handles the HTTP <code>POST</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Returns a short description of the servlet.
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }
}
